intelmq.bots.experts.cymru_whois package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.cymru_whois package

## Submodules

## intelmq.bots.experts.cymru_whois.expert module

`intelmq.bots.experts.cymru_whois.expert.` `BOT`

  alias of `intelmq.bots.experts.cymru_whois.expert.CymruExpertBot`

class `intelmq.bots.experts.cymru_whois.expert.` `CymruExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`, `intelmq.lib.mixins.cache.CacheMixin`

  Add ASN, netmask, AS name, country, registry and allocation time from the Cymru Whois DNS service

  `overwrite` = False
  `process`()
  `redis_cache_db`: int = 5
  `redis_cache_host`: str = '127.0.0.1'
  `redis_cache_password`: str = None
  `redis_cache_port`: int = 6379
  `redis_cache_ttl`: int = 86400

## intelmq.bots.experts.cymru_whois.lib module

## Module contents